summaryrefslogtreecommitdiff
path: root/lisp/obsolete/otodo-mode.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/obsolete/otodo-mode.el')
-rw-r--r--lisp/obsolete/otodo-mode.el7
1 files changed, 5 insertions, 2 deletions
diff --git a/lisp/obsolete/otodo-mode.el b/lisp/obsolete/otodo-mode.el
index 53220f0648..d551d167a9 100644
--- a/lisp/obsolete/otodo-mode.el
+++ b/lisp/obsolete/otodo-mode.el
@@ -272,7 +272,7 @@
This is useful in conjunction with `calendar' and `diary' if you use
-#include \"~/.todo-do\"
+#include \"~/.emacs.d/todo-do\"
in your diary file to include your todo list file as part of your
diary. With the default value \"*/*\" the diary displays each entry
@@ -284,10 +284,12 @@ the diary file somewhat."
:group 'todo)
(defcustom todo-file-do (locate-user-emacs-file "todo-do" ".todo-do")
"TODO mode list file."
+ :version "24.4" ; added locate-user-emacs-file
:type 'file
:group 'todo)
(defcustom todo-file-done (locate-user-emacs-file "todo-done" ".todo-done")
"TODO mode archive file."
+ :version "24.4" ; added locate-user-emacs-file
:type 'file
:group 'todo)
(defcustom todo-mode-hook nil
@@ -321,6 +323,7 @@ window."
Not in TODO format, but diary compatible.
Automatically generated when `todo-save-top-priorities' is non-nil."
+ :version "24.4" ; added locate-user-emacs-file
:type 'string
:group 'todo)
@@ -916,7 +919,7 @@ If INCLUDE-SEP is non-nil, return point after the separator."
["Quit" todo-quit t]
))
;; As calendar reads .todo-do before todo-mode is loaded.
;;;###autoload
(define-derived-mode todo-mode nil "TODO"
"Major mode for editing TODO lists."
@@ -916,7 +919,7 @@ If INCLUDE-SEP is non-nil, return point after the separator."
["Quit" todo-quit t]
))
-;; As calendar reads .todo-do before todo-mode is loaded.
+;; As calendar reads todo-file-do before todo-mode is loaded.
;;;###autoload
(define-derived-mode todo-mode nil "TODO"